pub struct ChainToPoolAndNetAdapter<B, P>where
B: BlockChain,
P: PoolAdapter,{ /* private fields */ }Expand description
Implementation of the ChainAdapter for the network. Gets notified when the accepted a new block, asking the pool to update its state and the network to broadcast the block
Implementations
Sourceimpl<B, P> ChainToPoolAndNetAdapter<B, P>where
B: BlockChain,
P: PoolAdapter,
impl<B, P> ChainToPoolAndNetAdapter<B, P>where
B: BlockChain,
P: PoolAdapter,
Sourcepub fn new(
tx_pool: Arc<RwLock<TransactionPool<B, P>>>,
hooks: Vec<Box<dyn ChainEvents + Send + Sync>>,
) -> Self
pub fn new( tx_pool: Arc<RwLock<TransactionPool<B, P>>>, hooks: Vec<Box<dyn ChainEvents + Send + Sync>>, ) -> Self
Construct a ChainToPoolAndNetAdapter instance.