pub enum ChainValidationMode {
EveryBlock,
Disabled,
}Expand description
Type of seeding the server will use to find other peers on the network.
Variants
EveryBlock
Run full chain validation after processing every block.
Disabled
Do not automatically run chain validation during normal block processing.